@@ -1,6 +1,9 @@
 from ...abstract_webtools import *
 from ..urlManager import *
 from ..requestManager import *
+from bs4 import BeautifulSoup
+import re, json
+
 class soupManager:
     """
     SoupManager is a class for managing and parsing HTML source code using BeautifulSoup.
@@ -39,25 +42,49 @@ class soupManager:
         - The SoupManager class is designed for parsing HTML source code using BeautifulSoup.
         - It provides various methods to extract data and discover elements within the source code.
     """
-    def __init__(self,url=None,source_code=None,url_mgr=None,req_mgr=None,soup=None, parse_type="html.parser"):
-        self.soup=[]
-        url = get_url(url=url,url_mgr=url_mgr)
-        self.url_mgr = get_url_mgr(url=url,url_mgr=url_mgr)
-        self.url=self.url_mgr.url
-        self.req_mgr = get_req_mgr(req_mgr=req_mgr,url=self.url,url_mgr=self.url_mgr,source_code=source_code)
-        self.parse_type = parse_type
-        source_code = source_code or self.req_mgr.source_code or self.req_mgr.source_code_bytes
-        if source_code:
-            source_code = str(source_code)
-        self.source_code = source_code or ''
-        self.soup= soup or BeautifulSoup(self.source_code, self.parse_type)
-        self.all_tags_and_attribute_names = self.get_all_tags_and_attribute_names()
-        self.all_tags = self.all_tags_and_attribute_names.get('tags')
-        self.all_attribute_names = self.all_tags_and_attribute_names.get('attributes')
-        self.all_tags_and_attributes = self.all_tags + self.all_attribute_names
-        
-        self._all_links_data = None
-        self._meta_tags_data = None
+
+    def __init__(self, url=None, source_code=None, req_mgr=None, parse_type="html.parser"):
+        self.url = url
+        self.req_mgr = req_mgr
+        self.source_code = (source_code or (req_mgr.source_code if req_mgr else "")) or ""
+        self.soup = BeautifulSoup(self.source_code, parse_type)
+
+    def all_meta(self):
+        out = []
+        for m in self.soup.find_all("meta"):
+            row = {}
+            for k in ("name","property","http-equiv","itemprop","charset","content"):
+                v = m.get(k)
+                if v: row[k] = v
+            if row: out.append(row)
+        return out
+
+    def citation_dict(self):
+        out = {}
+        for m in self.soup.find_all("meta"):
+            k = (m.get("name") or m.get("property") or "").lower()
+            if k.startswith("citation_") and m.get("content"):
+                out.setdefault(k, []).append(m["content"])
+        return out
+
+    def all_links(self):
+        res = []
+        for l in self.soup.find_all("link"):
+            rel = l.get("rel")
+            if isinstance(rel, list): rel = " ".join(rel)
+            res.append({
+                "rel": rel, "href": l.get("href"),
+                "type": l.get("type"), "title": l.get("title"), "hreflang": l.get("hreflang")
+            })
+        return res
+
+    def all_jsonld(self):
+        blocks = []
+        for s in self.soup.find_all("script", type=re.compile("application/ld\\+json", re.I)):
+            txt = s.get_text(strip=True)
+            try: blocks.append(json.loads(txt))
+            except Exception: blocks.append({"raw": txt})
+        return blocks
     def re_initialize(self):
         self.soup= BeautifulSoup(self.source_code, self.parse_type)
         self._all_links_data = None
